Detectors
=========

.. automodule:: stonesoup.detector
    :no-members:

.. automodule:: stonesoup.detector.base
    :show-inheritance:

TensorFlow
----------
.. automodule:: stonesoup.detector.tensorflow
    :show-inheritance:

TensorNets
----------
.. automodule:: stonesoup.detector.tensornets
    :show-inheritance:

